@@ -1,27 +1,27 @@
-/* Copyright (C) 1999-2001 Free Software Foundation, Inc.
-   This file is part of the GNU ICONV Library.
+/* Copyright (C) 1999-2002 Free Software Foundation, Inc.
+   This file is part of the GNU LIBICONV Library.
 
-   The GNU ICONV Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   The GNU LIBICONV Library is free software; you can redistribute it
+   and/or modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
 
-   The GNU ICONV Library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   The GNU LIBICONV Library is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public
-   License along with the GNU ICONV Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   License along with the GNU LIBICONV Library; see the file COPYING.LIB.
+   If not, write to the Free Software Foundation, Inc., 59 Temple Place -
+   Suite 330, Boston, MA 02111-1307, USA.  */
 
 /* When installed, this file is called "iconv.h". */
 
 #ifndef _LIBICONV_H
 #define _LIBICONV_H
 
-#define _LIBICONV_VERSION 0x0106    /* version number: (major<<8) + minor */
+#define _LIBICONV_VERSION 0x0108    /* version number: (major<<8) + minor */
 extern int _libiconv_version;       /* Likewise */
 
 /* We would like to #include any system header file which could define
@@ -51,11 +51,11 @@ typedef void* iconv_t;
 
 /* Get errno declaration and values. */
 #include <errno.h>
-/* Some systems, like SunOS 4, don't have EILSEQ. On these systems, define
-   EILSEQ ourselves, but don't define it as EINVAL, because iconv() callers
-   want to distinguish EINVAL and EILSEQ. */
+/* Some systems, like SunOS 4, don't have EILSEQ. Some systems, like BSD/OS,
+   have EILSEQ in a different header.  On these systems, define EILSEQ
+   ourselves. */
 #ifndef EILSEQ
-#define EILSEQ ENOENT
+#define EILSEQ 
 #endif
 
 
@@ -100,7 +100,15 @@ extern int iconvctl (iconv_t cd, int request, void* argument);
 #define ICONV_TRIVIALP            0  /* int *argument */
 #define ICONV_GET_TRANSLITERATE   1  /* int *argument */
 #define ICONV_SET_TRANSLITERATE   2  /* const int *argument */
+#define ICONV_GET_DISCARD_ILSEQ   3  /* int *argument */
+#define ICONV_SET_DISCARD_ILSEQ   4  /* const int *argument */
 
+/* Listing of locale independent encodings. */
+#define iconvlist libiconvlist
+extern void iconvlist (int (*do_one) (unsigned int namescount,
+                                      const char * const * names,
+                                      void* data),
+                       void* data);
 #endif
 
 
